smut/types

Due to visibility rules and the prohibition of circular imports, these types need to live in their own module.

Types

Errors that can happen when inserting a value into a new slot.

pub type SmutError {
  NewFailed(String)
  NewExited(String)
}

Constructors

  • NewFailed(String)

    Insertion of the value failed, or the write-controlling process failed to start.

  • NewExited(String)

    The write-controlling process exited; this shouldn’t happen and is probably indicative of some larger problem.

A handle to the table where shared, mutable state is stored.

pub type TableHandle
Search Document